@@ -25,10 +25,11 @@ import shutil
 import textwrap
 import time
 import urllib
+from collections.abc import Iterable, Mapping
 from dataclasses import dataclass
 from functools import partial
 from pathlib import Path
-from typing import TYPE_CHECKING, Dict, Iterable, Mapping, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Optional, Union
 from unittest.mock import patch
 
 import fsspec
@@ -255,7 +256,7 @@ class DatasetBuilder:
             Datasets Hub. If `True`, will get token from `"~/.huggingface"`.
         repo_id (`str`, *optional*):
             ID of the dataset repository.
-            Used to distinguish builders with the same name but not coming from the same namespace, for example "squad"
+            Used to distinguish builders with the same name but not coming from the same namespace, for example "rajpurkar/squad"
             and "lhoestq/squad" repo IDs. In the latter, the builder name would be "lhoestq___squad".
         data_files (`str` or `Sequence` or `Mapping`, *optional*):
             Path(s) to source data file(s).
@@ -524,7 +525,7 @@ class DatasetBuilder:
 
         ```py
         >>> from datasets import load_dataset_builder
-        >>> ds_builder = load_dataset_builder('rotten_tomatoes')
+        >>> ds_builder = load_dataset_builder('cornell-movie-review-data/rotten_tomatoes')
         >>> ds_builder.get_exported_dataset_info()
         DatasetInfo(description='', citation='', homepage='', license='', features={'speaker_id': Value(dtype='string', id=None), 'path': Value(dtype='string', id=None), 'audio': Audio(sampling_rate=16000, mono=True, decode=True, id=None), 'sentence': Value(dtype='string', id=None)}, post_processed=None, supervised_keys=None, builder_name=None, dataset_name=None, config_name='default', version=None, splits={'train': SplitInfo(name='train', num_bytes=1722002133, num_examples=11660, shard_lengths=None, dataset_name=None), 'test': SplitInfo(name='test', num_bytes=86120227, num_examples=760, shard_lengths=None, dataset_name=None)}, download_checksums=None, download_size=1475540500, post_processing_size=None, dataset_size=1808122360, size_in_bytes=None)
         ```
@@ -533,7 +534,7 @@ class DatasetBuilder:
 
     def _create_builder_config(
         self, config_name=None, custom_features=None, **config_kwargs
-    ) -> Tuple[BuilderConfig, str]:
+    ) -> tuple[BuilderConfig, str]:
         """Create and validate BuilderConfig object as well as a unique config id for this config.
         Raises ValueError if there are multiple builder configs and config_name and DEFAULT_CONFIG_NAME are None.
         config_kwargs override the defaults kwargs in config
@@ -624,7 +625,7 @@ class DatasetBuilder:
     @classproperty
     @classmethod
     @memoize()
-    def builder_configs(cls) -> Dict[str, BuilderConfig]:
+    def builder_configs(cls) -> dict[str, BuilderConfig]:
         """Dictionary of pre-defined configurations for this builder class."""
         configs = {config.name: config for config in cls.BUILDER_CONFIGS}
         if len(configs) != len(cls.BUILDER_CONFIGS):
@@ -782,7 +783,7 @@ class DatasetBuilder:
 
         ```py
         >>> from datasets import load_dataset_builder
-        >>> builder = load_dataset_builder("rotten_tomatoes")
+        >>> builder = load_dataset_builder("cornell-movie-review-data/rotten_tomatoes")
         >>> builder.download_and_prepare()
         ```
 
@@ -790,7 +791,7 @@ class DatasetBuilder:
 
         ```py
         >>> from datasets import load_dataset_builder
-        >>> builder = load_dataset_builder("rotten_tomatoes")
+        >>> builder = load_dataset_builder("cornell-movie-review-data/rotten_tomatoes")
         >>> builder.download_and_prepare("./output_dir", file_format="parquet")
         ```
 
@@ -799,7 +800,7 @@ class DatasetBuilder:
         ```py
         >>> from datasets import load_dataset_builder
         >>> storage_options = {"key": aws_access_key_id, "secret": aws_secret_access_key}
-        >>> builder = load_dataset_builder("rotten_tomatoes")
+        >>> builder = load_dataset_builder("cornell-movie-review-data/rotten_tomatoes")
         >>> builder.download_and_prepare("s3://my-bucket/my_rotten_tomatoes", storage_options=storage_options, file_format="parquet")
         ```
         """
@@ -1093,7 +1094,7 @@ class DatasetBuilder:
 
         ```py
         >>> from datasets import load_dataset_builder
-        >>> builder = load_dataset_builder('rotten_tomatoes')
+        >>> builder = load_dataset_builder('cornell-movie-review-data/rotten_tomatoes')
         >>> builder.download_and_prepare()
         >>> ds = builder.as_dataset(split='train')
         >>> ds
@@ -1114,7 +1115,7 @@ class DatasetBuilder:
                 "datasets.load_dataset() before trying to access the Dataset object."
             )
 
-        logger.debug(f'Constructing Dataset for split {split or ", ".join(self.info.splits)}, from {self._output_dir}')
+        logger.debug(f"Constructing Dataset for split {split or ', '.join(self.info.splits)}, from {self._output_dir}")
 
         # By default, return all splits
         if split is None:
@@ -1248,7 +1249,7 @@ class DatasetBuilder:
         self,
         split: Optional[str] = None,
         base_path: Optional[str] = None,
-    ) -> Union[Dict[str, IterableDataset], IterableDataset]:
+    ) -> Union[dict[str, IterableDataset], IterableDataset]:
         if is_remote_filesystem(self._fs):
             raise NotImplementedError(
                 f"Loading a streaming dataset cached in a {type(self._fs).__name__} is not supported yet."
@@ -1295,7 +1296,7 @@ class DatasetBuilder:
         """Run dataset transforms or add indexes"""
         return None
 
-    def _post_processing_resources(self, split: str) -> Dict[str, str]:
+    def _post_processing_resources(self, split: str) -> dict[str, str]:
         """Mapping resource_name -> resource_file_name"""
         return {}
 
@@ -1492,9 +1493,9 @@ class GeneratorBasedBuilder(DatasetBuilder):
                         pbar.update(content)
             # wrapping everything into lists for consistency with the multiprocessed code path
             assert result is not None, "Failed to retrieve results from prepare_split"
-            examples_per_job, bytes_per_job, features_per_job, shards_per_job, shard_lengths_per_job = [
+            examples_per_job, bytes_per_job, features_per_job, shards_per_job, shard_lengths_per_job = (
                 [item] for item in result
-            ]
+            )
         else:
             kwargs_per_job = [
                 {"gen_kwargs": gen_kwargs, "job_id": job_id, **_prepare_split_args}
@@ -1528,9 +1529,9 @@ class GeneratorBasedBuilder(DatasetBuilder):
                             # the content is the number of examples progress update
                             pbar.update(content)
 
-            assert (
-                None not in examples_per_job
-            ), f"Failed to retrieve results from prepare_split: result list {examples_per_job} still contains None - at least one worker failed to return its results"
+            assert None not in examples_per_job, (
+                f"Failed to retrieve results from prepare_split: result list {examples_per_job} still contains None - at least one worker failed to return its results"
+            )
 
         total_shards = sum(shards_per_job)
         total_num_examples = sum(examples_per_job)
@@ -1545,7 +1546,7 @@ class GeneratorBasedBuilder(DatasetBuilder):
         if total_shards > 1:
             # use the -SSSSS-of-NNNNN pattern
 
-            def _rename_shard(shard_and_job: Tuple[int]):
+            def _rename_shard(shard_and_job: tuple[int]):
                 shard_id, job_id = shard_and_job
                 global_shard_id = sum(shards_per_job[:job_id]) + shard_id
                 self._rename(
@@ -1583,7 +1584,7 @@ class GeneratorBasedBuilder(DatasetBuilder):
         split_info: SplitInfo,
         check_duplicate_keys: bool,
         job_id: int,
-    ) -> Iterable[Tuple[int, bool, Union[int, tuple]]]:
+    ) -> Iterable[tuple[int, bool, Union[int, tuple]]]:
         generator = self._generate_examples(**gen_kwargs)
         writer_class = ParquetWriter if file_format == "parquet" else ArrowWriter
         embed_local_files = file_format == "parquet"
@@ -1747,9 +1748,9 @@ class ArrowBasedBuilder(DatasetBuilder):
                         pbar.update(content)
             # wrapping everything into lists for consistency with the multiprocessed code path
             assert result is not None, "Failed to retrieve results from prepare_split"
-            examples_per_job, bytes_per_job, features_per_job, shards_per_job, shard_lengths_per_job = [
+            examples_per_job, bytes_per_job, features_per_job, shards_per_job, shard_lengths_per_job = (
                 [item] for item in result
-            ]
+            )
         else:
             kwargs_per_job = [
                 {"gen_kwargs": gen_kwargs, "job_id": job_id, **_prepare_split_args}
@@ -1783,9 +1784,9 @@ class ArrowBasedBuilder(DatasetBuilder):
                             # the content is the number of examples progress update
                             pbar.update(content)
 
-            assert (
-                None not in examples_per_job
-            ), f"Failed to retrieve results from prepare_split: result list {examples_per_job} still contains None - at least one worker failed to return its results"
+            assert None not in examples_per_job, (
+                f"Failed to retrieve results from prepare_split: result list {examples_per_job} still contains None - at least one worker failed to return its results"
+            )
 
         total_shards = sum(shards_per_job)
         total_num_examples = sum(examples_per_job)
@@ -1800,7 +1801,7 @@ class ArrowBasedBuilder(DatasetBuilder):
         if total_shards > 1:
             # use the -SSSSS-of-NNNNN pattern
 
-            def _rename_shard(shard_id_and_job: Tuple[int]):
+            def _rename_shard(shard_id_and_job: tuple[int]):
                 shard_id, job_id = shard_id_and_job
                 global_shard_id = sum(shards_per_job[:job_id]) + shard_id
                 self._rename(
@@ -1831,7 +1832,7 @@ class ArrowBasedBuilder(DatasetBuilder):
 
     def _prepare_split_single(
         self, gen_kwargs: dict, fpath: str, file_format: str, max_shard_size: int, job_id: int
-    ) -> Iterable[Tuple[int, bool, Union[int, tuple]]]:
+    ) -> Iterable[tuple[int, bool, Union[int, tuple]]]:
         gen_kwargs = {k: tracked_list(v) if isinstance(v, list) else v for k, v in gen_kwargs.items()}
         generator = self._generate_tables(**gen_kwargs)
         writer_class = ParquetWriter if file_format == "parquet" else ArrowWriter
