@@ -13,9 +13,11 @@ __all__ = [
     "Translation",
     "TranslationVariableLanguages",
     "Video",
+    "Pdf",
 ]
 from .audio import Audio
 from .features import Array2D, Array3D, Array4D, Array5D, ClassLabel, Features, LargeList, Sequence, Value
 from .image import Image
+from .pdf import Pdf
 from .translation import Translation, TranslationVariableLanguages
 from .video import Video
