@@ -1,5 +1,3 @@
-from typing import List
-
 import datasets
 
 from ..folder_based_builder import folder_based_builder
@@ -22,7 +20,7 @@ class AudioFolder(folder_based_builder.FolderBasedBuilder):
     BASE_FEATURE = datasets.Audio
     BASE_COLUMN_NAME = "audio"
     BUILDER_CONFIG_CLASS = AudioFolderConfig
-    EXTENSIONS: List[str]  # definition at the bottom of the script
+    EXTENSIONS: list[str]  # definition at the bottom of the script
 
 
 # Obtained with:
