@@ -2,7 +2,7 @@ import io
 import json
 import re
 from itertools import islice
-from typing import Any, Callable, Dict, List
+from typing import Any, Callable
 
 import fsspec
 import numpy as np
@@ -18,10 +18,10 @@ logger = datasets.utils.logging.get_logger(__name__)
 
 class WebDataset(datasets.GeneratorBasedBuilder):
     DEFAULT_WRITER_BATCH_SIZE = 100
-    IMAGE_EXTENSIONS: List[str]  # definition at the bottom of the script
-    AUDIO_EXTENSIONS: List[str]  # definition at the bottom of the script
-    VIDEO_EXTENSIONS: List[str]  # definition at the bottom of the script
-    DECODERS: Dict[str, Callable[[Any], Any]]  # definition at the bottom of the script
+    IMAGE_EXTENSIONS: list[str]  # definition at the bottom of the script
+    AUDIO_EXTENSIONS: list[str]  # definition at the bottom of the script
+    VIDEO_EXTENSIONS: list[str]  # definition at the bottom of the script
+    DECODERS: dict[str, Callable[[Any], Any]]  # definition at the bottom of the script
     NUM_EXAMPLES_FOR_FEATURES_INFERENCE = 5
 
     @classmethod
